<?php

namespace App\Http\Controllers\Admin;

use DateTimeZone;
use Inertia\Inertia;
use Inertia\Response;
use App\Traits\Dotenv;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\ExchangeRate;
use App\Models\Option;
use App\Models\VirtualCurrency;
use App\Traits\Uploader;

class DeveloperSettingsController extends Controller
{
    use Dotenv, Uploader;

    public function __construct()
    {
        $this->middleware('permission:developer-settings');
    }

    /**
     * Display the specified resource.
     *
     * @param  string  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id): Response
    {
        $segments = request()->segments();

        $buttons = [
            [
                'name' => __('Back to dashboard'),
                'url' => url('/admin/dashboard')
            ],
        ];

        if ($id == 'app-settings') {
            $tzlist = DateTimeZone::listIdentifiers(DateTimeZone::ALL);
            $languages = get_option('languages');
            $appName      = env('APP_NAME');
            $appDebug     = env('APP_DEBUG');
            $timeZone     = env('TIME_ZONE', 'UTC');
            $default_lang = env('DEFAULT_LANG', 'en');

            return Inertia::render('Admin/Developer/App', compact('id', 'tzlist', 'languages', 'appName', 'appDebug', 'timeZone', 'default_lang', 'segments', 'buttons'));
        } elseif ($id == 'mail-settings') {
            $mailDriver       = env('MAIL_DRIVER_TYPE') == 'MAIL_DRIVER' ? env('MAIL_DRIVER') : env('MAIL_MAILER');
            $QUEUE_MAIL       = env('QUEUE_MAIL');
            $MAIL_DRIVER_TYPE = env('MAIL_DRIVER_TYPE');
            $MAIL_HOST        = env('MAIL_HOST');
            $MAIL_PORT        = env('MAIL_PORT');
            $MAIL_USERNAME    = env('MAIL_USERNAME');
            $MAIL_PASSWORD    = env('MAIL_PASSWORD');
            $MAIL_ENCRYPTION  = env('MAIL_ENCRYPTION');
            $MAIL_FROM_ADDRESS = env('MAIL_FROM_ADDRESS');
            $MAIL_FROM_NAME   = env('MAIL_FROM_NAME');
            $MAIL_TO          = env('MAIL_TO');

            return Inertia::render('Admin/Developer/Smtp', compact(
                'id',
                'mailDriver',
                'segments',
                'buttons',
                'QUEUE_MAIL',
                'MAIL_DRIVER_TYPE',
                'MAIL_HOST',
                'MAIL_PORT',
                'MAIL_USERNAME',
                'MAIL_PASSWORD',
                'MAIL_ENCRYPTION',
                'MAIL_FROM_ADDRESS',
                'MAIL_FROM_NAME',
                'MAIL_TO',
            ));
        } elseif ($id == 'newsletter-settings') {

            $NEWSLETTER_API_KEY = env('NEWSLETTER_API_KEY');
            $NEWSLETTER_LIST_ID = env('NEWSLETTER_LIST_ID');

            return Inertia::render('Admin/Developer/Newsletter', compact(
                'id',
                'NEWSLETTER_API_KEY',
                'NEWSLETTER_LIST_ID',
                'segments',
                'buttons'
            ));
        } elseif ($id == 'storage-settings') {
            $FILESYSTEM_DISK = env('FILESYSTEM_DISK');
            $WAS_ACCESS_KEY_ID = env('WAS_ACCESS_KEY_ID');
            $SECRET_ACCESS_KEY = env('SECRET_ACCESS_KEY');
            $WAS_DEFAULT_REGION = env('WAS_DEFAULT_REGION');
            $WAS_BUCKET = env('WAS_BUCKET');
            $WAS_ENDPOINT = env('WAS_ENDPOINT');

            return Inertia::render('Admin/Developer/Storage', compact(
                'id',
                'FILESYSTEM_DISK',
                'WAS_ACCESS_KEY_ID',
                'SECRET_ACCESS_KEY',
                'WAS_DEFAULT_REGION',
                'WAS_BUCKET',
                'WAS_ENDPOINT',
                'segments',
                'buttons'
            ));
        } elseif ($id == 'stripe-settings') {
            $STRIPE_API_KEY = env('STRIPE_API_KEY');
            $STRIPE_PUBLIC_API_KEY = env('STRIPE_PUBLIC_API_KEY');
            $STRIPE_CURRENCY = env('STRIPE_CURRENCY');
            $creditCardCurrencies = ['usd', 'eur', 'gbp'];
            return Inertia::render('Admin/Developer/Stripe', compact(
                'id',
                'STRIPE_API_KEY',
                'STRIPE_PUBLIC_API_KEY',
                'STRIPE_CURRENCY',
                'creditCardCurrencies',
            ));
        } elseif ($id == 'twilio-settings') {
            $TWILIO_ACCOUNT_SID = env('TWILIO_ACCOUNT_SID');
            $TWILIO_AUTH_TOKEN = env('TWILIO_AUTH_TOKEN');
            $TWILIO_NUMBER = env('TWILIO_NUMBER');
            return Inertia::render('Admin/Developer/Twilio', compact(
                'id',
                'TWILIO_ACCOUNT_SID',
                'TWILIO_AUTH_TOKEN',
                'TWILIO_NUMBER',
            ));
        } elseif ($id == 'features-settings') {
            $EMAIL_VERIFICATION = env('EMAIL_VERIFICATION');
            $PHONE_VERIFICATION = env('PHONE_VERIFICATION');
            $KYC_VERIFICATION = env('KYC_VERIFICATION');
            return Inertia::render('Admin/Developer/Features', compact(
                'id',
                'EMAIL_VERIFICATION',
                'PHONE_VERIFICATION',
                'KYC_VERIFICATION',
            ));
        } elseif ($id == 'currency-settings') {
            $virtualCurrency = VirtualCurrency::firstWhere('is_default', 1);
            $rates = ExchangeRate::query()
                ->where('virtual_currency_id', $virtualCurrency->id)
                ->with('exchange_currency:id,currency')
                ->get();
            $currencies = VirtualCurrency::where('id', '!=', $virtualCurrency->id)
                ->get()
                ->map(function ($currency) {
                    return [
                        'id' => $currency->id,
                        'currency' => $currency->currency,
                    ];
                });
            $base_currency = get_option('base_currency');
            return Inertia::render('Admin/Developer/Currency', compact(
                'id',
                'virtualCurrency',
                'rates',
                'currencies',
                'base_currency',
            ));
        } elseif ($id == 'social-login-settings') {

            $GOOGLE_CLIENT_ID = env('GOOGLE_CLIENT_ID');
            $GOOGLE_CLIENT_SECRET = env('GOOGLE_CLIENT_SECRET');
            $GOOGLE_REDIRECT_URL = env('GOOGLE_REDIRECT_URL');

            $FACEBOOK_CLIENT_ID = env('FACEBOOK_CLIENT_ID');
            $FACEBOOK_CLIENT_SECRET = env('FACEBOOK_CLIENT_SECRET');
            $FACEBOOK_REDIRECT_URL = env('FACEBOOK_REDIRECT_URL');

            return Inertia::render('Admin/Developer/SocialLogin', compact(
                'id',
                'GOOGLE_CLIENT_ID',
                'GOOGLE_CLIENT_SECRET',
                'GOOGLE_REDIRECT_URL',
                'FACEBOOK_CLIENT_ID',
                'FACEBOOK_CLIENT_SECRET',
                'FACEBOOK_REDIRECT_URL',
                'segments',
                'buttons'
            ));
        } elseif ($id == 'cookie-settings') {

            $COOKIE_CONSENT = env('COOKIE_CONSENT');
            $cookieData = json_decode(file_get_contents(database_path('json/cookie_data.json')), true);
            return Inertia::render('Admin/Developer/Cookie', compact(
                'id',
                'COOKIE_CONSENT',
                'cookieData',
                'segments',
                'buttons'
            ));
        }

        abort(404);
    }


    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {

        if ($id == 'app-settings') {
            $this->editEnv('APP_NAME', Str::slug($request->APP_NAME));
            $this->editEnv('APP_DEBUG', filter_var($request->APP_DEBUG, FILTER_VALIDATE_BOOLEAN), true);
            $this->editEnv('TIME_ZONE', $request->TIME_ZONE);
            $this->editEnv('DEFAULT_LANG', $request->DEFAULT_LANG ?? 'en');
        } elseif ($id == 'storage-settings') {
            $this->editEnv('FILESYSTEM_DISK', $request->FILESYSTEM_DISK);
            $this->editEnv('WAS_ACCESS_KEY_ID', $request->WAS_ACCESS_KEY_ID);
            $this->editEnv('SECRET_ACCESS_KEY', $request->SECRET_ACCESS_KEY);
            $this->editEnv('WAS_DEFAULT_REGION', $request->WAS_DEFAULT_REGION);
            $this->editEnv('WAS_BUCKET', $request->WAS_BUCKET);
            $this->editEnv('WAS_ENDPOINT', $request->WAS_ENDPOINT);
        } elseif ($id == 'newsletter-settings') {

            $this->editEnv('NEWSLETTER_API_KEY', $request->NEWSLETTER_API_KEY);
            $this->editEnv('NEWSLETTER_LIST_ID', $request->NEWSLETTER_LIST_ID);
        } elseif ($id == 'mail-settings') {

            $this->editEnv('QUEUE_MAIL', filter_var($request->QUEUE_MAIL, FILTER_VALIDATE_BOOLEAN), true);
            $this->editEnv('MAIL_DRIVER_TYPE', $request->MAIL_DRIVER_TYPE);
            $this->editEnv($request->MAIL_DRIVER_TYPE, $request->MAIL_DRIVER);
            $this->editEnv('MAIL_HOST', $request->MAIL_HOST);
            $this->editEnv('MAIL_PORT', $request->MAIL_PORT);
            $this->editEnv('MAIL_USERNAME', $request->MAIL_USERNAME);
            $this->editEnv('MAIL_PASSWORD', $request->MAIL_PASSWORD);
            $this->editEnv('MAIL_ENCRYPTION', $request->MAIL_ENCRYPTION);
            $this->editEnv('MAIL_FROM_ADDRESS', $request->MAIL_FROM_ADDRESS);
            $this->editEnv('MAIL_FROM_NAME', $request->MAIL_FROM_NAME);
            $this->editEnv('MAIL_TO', $request->MAIL_TO);
        } elseif ($id == 'stripe-settings') {
            $this->editEnv('STRIPE_API_KEY', $request->STRIPE_API_KEY);
            $this->editEnv('STRIPE_PUBLIC_API_KEY', $request->STRIPE_PUBLIC_API_KEY);
            $this->editEnv('STRIPE_CURRENCY', $request->STRIPE_CURRENCY);
        } elseif ($id == 'twilio-settings') {
            $this->editEnv('PHONE_VERIFICATION', $request->PHONE_VERIFICATION, true);
            $this->editEnv('TWILIO_ACCOUNT_SID', $request->TWILIO_ACCOUNT_SID);
            $this->editEnv('TWILIO_AUTH_TOKEN', $request->TWILIO_AUTH_TOKEN);
            $this->editEnv('TWILIO_NUMBER', $request->TWILIO_NUMBER);
        } elseif ($id == 'features-settings') {
            $this->editEnv('EMAIL_VERIFICATION', $request->EMAIL_VERIFICATION, true);
            $this->editEnv('PHONE_VERIFICATION', $request->PHONE_VERIFICATION, true);
            $this->editEnv('KYC_VERIFICATION', $request->KYC_VERIFICATION, true);
        } elseif ($id == 'currency-settings') {
            $request->validate([
                'preview' => request()->hasFile('preview') ? 'image' : 'nullable|string',
                'currency' => 'required|string',
                'precision' => 'required|integer|min:2',
            ]);
            $virtualCurrency = VirtualCurrency::where('id', $request->virtual_currency_id)
                ->where('is_default', 1)->firstOrFail();

            if ($request->hasFile('preview')) {
                $preview = $this->uploadFile('preview');
            }
            $virtualCurrency->update([
                'currency' => str()->lower($request->currency),
                'is_default' => 1,
                'precision' => $request->precision,
                'preview' => $preview ?? $virtualCurrency->preview
            ]);
            $option = Option::firstOrNew(['key' => 'base_currency']);
            $optionValue = [
                'name' => $virtualCurrency->currency,
                'icon' => $request->icon,
                'position' => $request->position
            ];
            $option->value = $optionValue;
            $option->save();
            if (request()->filled('rates')) {
                $request->validate(['rates' => 'array']);
                foreach (request()->rates as $rate) {
                    $virtualCurrency->rates()->updateOrCreate([
                        'virtual_currency_exchange_id' => $rate['id'],
                    ], ['rate' => $rate['rate']]);
                }
            }
        } elseif ($id == 'cookie-settings') {
            $this->editEnv('COOKIE_CONSENT', $request->COOKIE_CONSENT, true);
            file_put_contents(database_path('json/cookie_data.json'), json_encode($request->cookieData));
        }

        return back();
    }
}
