<?php

namespace App\Http\Controllers\User;

use Inertia\Inertia;
use App\Models\CardOrder;
use App\Models\CreditCard;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class CardOrderController extends Controller
{
    public function index(Request $request)
    {
        $segments = request()->segments();

        $orders = CardOrder::query()->where('user_id', auth()->id());

        if (!empty($request->search)) {
            if ($request->type == 'email') {
                $orders = $orders->whereHas('user', function ($q) use ($request) {
                    return $q->where('email', $request->search);
                });
            } else {
                $orders = $orders->where($request->type, 'LIKE', '%' . $request->search . '%');
            }
        }

        $orders = $orders->with('user', 'card', 'gateway')->latest()->paginate(20);

        $totalOrders = CardOrder::where('user_id', auth()->id())->count();
        $totalPendingOrders = CardOrder::where('status', 'pending')->where('user_id', auth()->id())->count();
        $totalApprovedOrders = CardOrder::where('status', 'approved')->where('user_id', auth()->id())->count();
        $totalRejectedOrders = CardOrder::where('status', 'rejected')->where('user_id', auth()->id())->count();
        $type = $request->type ?? 'email';

        return Inertia::render('User/CardOrder/Index', [
            'segments' => $segments,
            'orders' => $orders,
            'request' => $request,
            'totalOrders' => $totalOrders,
            'totalPendingOrders' => $totalPendingOrders,
            'totalApprovedOrders' => $totalApprovedOrders,
            'totalRejectedOrders' => $totalRejectedOrders,
            'type' => $type,
        ]);
    }

    public function show($id)
    {
        $order  = CardOrder::with('user', 'card', 'gateway')->findOrFail($id);
        $creditCard = CreditCard::with(['user' => [
            'country',
            'state',
            'city',
        ], 'card:id,card_variant', 'cardHolder'])
            ->where('card_order_id', $order->id)->first();

        $invoice_data = get_option('invoice_data');

        return Inertia::render('User/CardOrder/Show', [
            'order' => $order,
            'invoice_data' => $invoice_data,
            'meta' => $order->meta,
            'creditCard' => $creditCard ?? null,
        ]);
    }
}
