<?php

namespace App\Http\Controllers\User;

use App\Helpers\Toastr;
use App\Models\Gateway;
use App\Models\Notification;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use App\Models\Card;
use App\Models\CardOrder;
use App\Traits\Uploader;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Session;

class CardPayController extends Controller
{
    use Uploader;
    public function store(Request $request)
    {
        /** @var \App\Models\User */
        $user = Auth::user();

        $user->validatePlan('cards');

        $card = Card::where('status', 'active')->findOrFail($request->card_id);
        $gateway  = Gateway::where('status', 1)->findOrFail($request->gateway_id);
        $total  = $request->total;
        $deposit_fee = $total * $user->plan_data['deposit_fee']['value'] / 100;
        $with_deposit_fee = $total + $deposit_fee ?? 0;
        $subTotal  = ($with_deposit_fee * $gateway->multiply) + $gateway->charge;

        if ($gateway->min_amount > $subTotal) {
            return redirect()->back()->with('danger', __('The minimum transaction amount is ' . $gateway->min_amount));
        }
        if ($gateway->max_amount != -1) {
            if ($gateway->max_amount < $subTotal) {
                return redirect()->back()->with('danger', __('The maximum transaction amount is ' . $gateway->max_amount));
            }
        }

        if ($gateway->is_auto == 0) {
            $request->validate([
                'manualPayment.comment' => ['required', 'string', 'max:500'],
                'manualPayment.image' => ['required', 'image', 'max:2048'], // 2MB
            ]);

            $payment_data['comment'] = $request->input('manualPayment.comment');
            $image = $this->saveFile($request, 'manualPayment.image');
            $payment_data['screenshot'] = $image;
            $payment_data['comment'] = $request->input('manualPayment.comment');
        }

        Session::put('card_id', $card->id);
        Session::put('deposit_fee', $deposit_fee ?? 0);
        $payment_data['currency']   = $gateway->currency ?? 'USD';
        $payment_data['email']      = auth()->user()->email;
        $payment_data['name']       = auth()->user()->name;
        $payment_data['phone']      = $request->phone;
        $payment_data['billName']   = 'Card Name: ' . $card->title;
        $payment_data['amount']     = $with_deposit_fee;
        $payment_data['test_mode']  = $gateway->test_mode;
        $payment_data['charge']     = $gateway->charge ?? 0;
        $payment_data['pay_amount'] =  number_format($subTotal, 0, '.', '');
        $payment_data['gateway_id']  = $gateway->id;

        $callback['success'] = route('user.card.pay.status.update', 'success');
        $callback['fail'] = route('user.card.pay.status.update', 'failed');
        $callback['coingate_webhook_route'] = 'coingate.card-pay.callback';
        Session::put('call_back', $callback);

        if (!empty($gateway->data)) {
            foreach (json_decode($gateway->data ?? '') ?? [] as $key => $info) {
                $payment_data[$key] = $info;
            };
        }

        return $gateway->namespace::make_payment($payment_data);
    }

    public function update($status)
    {

        abort_if(!Session::has('call_back'), 404);

        return $status == 'success' ? $this->success() : $this->failed();
    }

    private function success()
    {
        abort_if(!Session::has('payment_info'), 404);

        $paymentInfo = Session::get('payment_info');
        $card = Card::where('status', 1)->findOrFail(Session::get('card_id'));

        Session::forget('payment_info');
        Session::forget('call_back');
        Session::forget('card_id');

        DB::transaction(function () use ($paymentInfo, $card) {
            $order = new CardOrder;
            $order->card_id     = $card->id;
            $order->payment_id  = $paymentInfo['payment_id'];
            $order->user_id     = auth()->id();
            $order->gateway_id  = $paymentInfo['gateway_id'];
            $order->amount      = $paymentInfo['amount'];

            $order->order_uid      = session('order_uid');

            $order->ip_address  = request()->ip();
            $order->status      = $paymentInfo['status'] ?? 1;
            $order->deposit_fee =  Session::get('deposit_fee');
            if (isset($paymentInfo['meta'])) {
                $order->meta    = $paymentInfo['meta'];
            }
            $order->save();

            Notification::create([
                'user_id' => auth()->id(),
                'title' => __('New Card Purchased'),
                'comment' => __('A User has purchased a card'),
                'url' => route('admin.card-orders.show', $order->id),
            ]);
        });

        $message =  __('Your payment is complete admin will review this payment manually for approval.');

        Toastr::success($message);

        return to_route('user.card-orders.index')->with('success', $message);
    }

    private function failed()
    {
        Session::forget('payment_info');
        Session::forget('call_back');
        Session::flash('error', true);

        $message = __('Your payment request is failed');

        Toastr::danger($message);
        return to_route('user.card-orders.index')->with('danger', $message);;
    }
}
