<?php

namespace App\Http\Controllers\Web;

use App\Http\Controllers\Controller;
use App\Mail\ContactMail;
use App\Helpers\SeoMeta;
use App\Helpers\Toastr;
use App\Traits\Seo;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Session;
use Inertia\Inertia;

class ContactController extends Controller
{
    use Seo;

    public function index()
    {
        $contact = get_option('contact_page', true);

        SeoMeta::init('seo_contact');
        return Inertia::render('Web/Contact', [
            'contact' => $contact,
        ]);
    }

    public function store(Request $request)
    {
        $request->validate([
            'name' => ['required', 'string', 'max:40'],
            'email' => ['required', 'email', 'max:40'],
            'subject' => 'required|max:100',
            'message' => 'required|max:500',
        ]);

        try {
            $data['name'] = $request->name;
            $data['email'] = $request->email;
            $data['subject'] = $request->subject;
            $data['message'] = $request->message;

            env('QUEUE_MAIL') == true ? Mail::to(env('MAIL_TO'))->queue(new ContactMail($data)) : Mail::to(env('MAIL_TO'))->send(new ContactMail($data));

            Toastr::success(__('Message sent successfully'));
        } catch (Exception $e) {
            Toastr::danger($e->getMessage());
        }

        return back();
    }
}
